@@ -44,6 +44,7 @@ namespace eval portconfigure {
     # configure_get_default_compiler is fairly expensive, so cache the result
     variable recompute_default_compiler 1
     variable cached_default_compiler {}
+    variable no_default_compiler_allowed 0
 }
 
 
@@ -400,6 +401,10 @@ proc portconfigure::configure_start {args} {
     }
     ui_debug "Preferred compilers: ${compiler.fallback}"
     ui_debug "Using compiler '$compiler_name'"
+    variable no_default_compiler_allowed
+    if {$no_default_compiler_allowed} {
+        ui_warn_once no_default_compiler_allowed "All compilers are either blacklisted or unavailable; defaulting to first fallback option"
+    }
 
     # Additional ccache directory setup
     if {${configure.ccache}} {
@@ -788,6 +793,7 @@ proc portconfigure::configure_get_default_compiler {} {
         return $cached_default_compiler
     }
     set recompute_default_compiler 0
+    variable no_default_compiler_allowed 0
 
     global compiler.blacklist compiler.fallback compiler.whitelist
     if {${compiler.whitelist} ne ""} {
@@ -829,7 +835,9 @@ proc portconfigure::configure_get_default_compiler {} {
             return $compiler
         }
     }
-    ui_warn "All compilers are either blacklisted or unavailable; defaulting to first fallback option"
+    # Default to first compiler in the fallback list, and set a flag
+    # so that a warning can be printed at an appropriate time.
+    set no_default_compiler_allowed 1
     set cached_default_compiler [lindex ${compiler.fallback} 0]
     return $cached_default_compiler
 }
