@@ -1,8 +1,7 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
 # portdistfiles.tcl
-# $Id: portdistfiles.tcl 52800 2009-06-23 10:27:26Z toby@macports.org $
 #
-# Copyright (c) 2008 MacPorts Project
+# Copyright (c) 2008-2011 The MacPorts Project
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -13,7 +12,7 @@
 # 2. Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-# 3. Neither the name of Apple Computer, Inc. nor the names of its contributors
+# 3. Neither the name of The MacPorts Project nor the names of its contributors
 #    may be used to endorse or promote products derived from this software
 #    without specific prior written permission.
 # 
@@ -48,33 +47,38 @@ namespace eval portdistfiles {
 set_ui_prefix
 
 proc portdistfiles::distfiles_start {args} {
-    global UI_PREFIX name
-    ui_msg "$UI_PREFIX [format [msgcat::mc "Distfiles for %s"] ${name}]"
+    global UI_PREFIX subport
+    ui_notice "$UI_PREFIX [format [msgcat::mc "Distfiles for %s"] ${subport}]"
 }
 
 proc portdistfiles::distfiles_main {args} {
-    global UI_PREFIX master_sites checksums_array
+    global master_sites patch_sites patchfiles checksums_array \
+           portdbpath dist_subdir all_dist_files
     
     # give up on ports that do not provide URLs
-    if {$master_sites == "{}"} {
+    if {(![info exists master_sites] || $master_sites eq "{}")
+        && (![info exists patchfiles] || ![info exists patch_sites] || $patch_sites eq "{}")} {
         return 0
     }
 
     # from portfetch... process the sites, files and patches
-    set fetch_urls {}
+    set fetch_urls [list]
     portfetch::checkfiles fetch_urls
 
+    # also give up on ports that don't have any distfiles
+    if {![info exists all_dist_files]} {
+        return 0
+    }
+
     # get checksum data from the portfile and parse it
-    set checksums_str [option checksums]
-    set result [portchecksum::parse_checksums $checksums_str]
+    set result [portchecksum::parse_checksums [option checksums]]
 
+    global portfetch::urlmap
     foreach {url_var distfile} $fetch_urls {
-        global portfetch::urlmap
-
-        ui_msg "\[$distfile\]"
+        ui_msg "\[$distfile\] [file join $portdbpath distfiles $dist_subdir $distfile]"
 
         # print checksums if available
-        if {$result == "yes" && [array get checksums_array $distfile] != ""} {
+        if {$result eq "yes" && [info exists checksums_array($distfile)]} {
             foreach {type sum} $checksums_array($distfile) {
                 ui_msg " $type: $sum"
             }
@@ -82,7 +86,7 @@ proc portdistfiles::distfiles_main {args} {
 
         # determine sites to download from
         if {![info exists urlmap($url_var)]} {
-            set urlmap($url_var) $master_sites
+            set urlmap($url_var) $urlmap(master_sites)
         }
         
         # determine URLs to download
